import { AfterViewInit, EventEmitter, PipeTransform, TemplateRef } from '@angular/core';
import { ChangeDetectorRef, ElementRef, OnDestroy } from '@angular/core';
import { IButtonGroupEventArgs } from '../buttonGroup/buttonGroup.component';
import { IQueryBuilderResourceStrings } from '../core/i18n/query-builder-resources';
import { PlatformUtil } from '../core/utils';
import { FilteringLogic, IFilteringExpression } from '../data-operations/filtering-expression.interface';
import { IExpressionTree, IFilteringExpressionsTree } from '../data-operations/filtering-expressions-tree';
import { IgxOverlayOutletDirective } from '../directives/toggle/toggle.directive';
import { FieldType, EntityType } from '../grids/common/grid.interface';
import { IgxSelectComponent } from '../select/select.component';
import { OverlaySettings } from '../services/overlay/utilities';
import { IgxQueryBuilderHeaderComponent } from './query-builder-header.component';
import { IChangeCheckboxEventArgs } from "../checkbox/checkbox.component";
import { ISelectionEventArgs } from '../drop-down/drop-down.common';
import { IgxQueryBuilderSearchValueTemplateDirective } from './query-builder.directives';
import { IgxQueryBuilderComponent } from './query-builder.component';
import * as i0 from "@angular/core";
export declare class IgxFieldFormatterPipe implements PipeTransform {
    transform(value: any, formatter: (v: any, data: any, fieldData?: any) => any, rowData: any, fieldData?: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxFieldFormatterPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IgxFieldFormatterPipe, "fieldFormatter", true>;
}
/**
 * @hidden @internal
 *
 * Internal class usage
 */
declare class ExpressionItem {
    parent: ExpressionGroupItem;
    selected: boolean;
    expanded: boolean;
    constructor(parent?: ExpressionGroupItem);
}
/**
 * @hidden @internal
 *
 * Internal class usage
 */
declare class ExpressionGroupItem extends ExpressionItem {
    operator: FilteringLogic;
    children: ExpressionItem[];
    constructor(operator: FilteringLogic, parent?: ExpressionGroupItem);
}
/**
 * @hidden @internal
 *
 * Internal class usage
 */
declare class ExpressionOperandItem extends ExpressionItem {
    expression: IFilteringExpression;
    inEditMode: boolean;
    inAddMode: boolean;
    hovered: boolean;
    fieldLabel: string;
    constructor(expression: IFilteringExpression, parent: ExpressionGroupItem);
}
export declare class IgxQueryBuilderTreeComponent implements AfterViewInit, OnDestroy {
    cdr: ChangeDetectorRef;
    protected platform: PlatformUtil;
    protected el: ElementRef;
    private elRef;
    protected _localeId: string;
    /**
     * @hidden @internal
     */
    get getClass(): string;
    entities: EntityType[];
    queryBuilder: IgxQueryBuilderComponent;
    searchValueTemplate: TemplateRef<IgxQueryBuilderSearchValueTemplateDirective>;
    get parentExpression(): ExpressionOperandItem;
    set parentExpression(value: ExpressionOperandItem);
    /**
    * Returns the fields.
    */
    get fields(): FieldType[];
    /**
     * Sets the fields.
     */
    set fields(fields: FieldType[]);
    /**
    * Returns the expression tree.
    */
    get expressionTree(): IExpressionTree;
    /**
     * Sets the expression tree.
     */
    set expressionTree(expressionTree: IExpressionTree);
    /**
     * Gets the `locale` of the query builder.
     * If not set, defaults to application's locale.
     */
    get locale(): string;
    /**
     * Sets the `locale` of the query builder.
     * Expects a valid BCP 47 language tag.
     */
    set locale(value: string);
    /**
     * Sets the resource strings.
     * By default it uses EN resources.
     */
    set resourceStrings(value: IQueryBuilderResourceStrings);
    /**
     * Returns the resource strings.
     */
    get resourceStrings(): IQueryBuilderResourceStrings;
    /**
     * Event fired as the expression tree is changed.
     *
     * ```html
     *  <igx-query-builder (expressionTreeChange)='onExpressionTreeChange()'></igx-query-builder>
     * ```
     */
    expressionTreeChange: EventEmitter<IExpressionTree>;
    inEditModeChange: EventEmitter<ExpressionOperandItem>;
    protected entitySelect: IgxSelectComponent;
    private selectedReturnFieldsCombo;
    private fieldSelect;
    private conditionSelect;
    private searchValueInput;
    private picker;
    private addRootAndGroupButton;
    private addConditionButton;
    private entityChangeDialog;
    /**
     * @hidden @internal
     */
    headerContent: IgxQueryBuilderHeaderComponent;
    protected set editingInputsContainer(value: ElementRef);
    /** @hidden */
    protected get editingInputsContainer(): ElementRef;
    protected set addModeContainer(value: ElementRef);
    /** @hidden */
    protected get addModeContainer(): ElementRef;
    protected set currentGroupButtonsContainer(value: ElementRef);
    /** @hidden */
    protected get currentGroupButtonsContainer(): ElementRef;
    private contextMenuToggle;
    private chips;
    private expressionsContainer;
    private overlayOutlet;
    private innerQueries;
    /**
     * @hidden @internal
     */
    rootGroup: ExpressionGroupItem;
    /**
     * @hidden @internal
     */
    selectedExpressions: ExpressionOperandItem[];
    /**
     * @hidden @internal
     */
    currentGroup: ExpressionGroupItem;
    /**
     * @hidden @internal
     */
    contextualGroup: ExpressionGroupItem;
    /**
     * @hidden @internal
     */
    filteringLogics: any;
    /**
     * @hidden @internal
     */
    selectedCondition: string;
    /**
     * @hidden @internal
     */
    searchValue: {
        value: any;
    };
    /**
     * @hidden @internal
     */
    pickerOutlet: IgxOverlayOutletDirective | ElementRef;
    /**
     * @hidden @internal
     */
    returnFieldSelectOverlaySettings: OverlaySettings;
    /**
     * @hidden @internal
     */
    entitySelectOverlaySettings: OverlaySettings;
    /**
     * @hidden @internal
     */
    fieldSelectOverlaySettings: OverlaySettings;
    /**
     * @hidden @internal
     */
    conditionSelectOverlaySettings: OverlaySettings;
    private destroy$;
    private _parentExpression;
    private _initialExpressionTree;
    private _selectedEntity;
    private _selectedReturnFields;
    private _selectedField;
    private _clickTimer;
    private _dblClickDelay;
    private _preventChipClick;
    private _editingInputsContainer;
    private _addModeContainer;
    private _currentGroupButtonsContainer;
    private _addModeExpression;
    private _editedExpression;
    private _selectedGroups;
    private _expandedExpressions;
    private _fields;
    private _expressionTree;
    private _locale;
    private _entityNewValue;
    private _resourceStrings;
    get level(): number;
    private _positionSettings;
    private _overlaySettings;
    constructor(cdr: ChangeDetectorRef, platform: PlatformUtil, el: ElementRef, elRef: ElementRef, _localeId: string);
    /**
     * @hidden @internal
     */
    ngAfterViewInit(): void;
    /**
     * @hidden @internal
     */
    ngOnDestroy(): void;
    /**
     * @hidden @internal
     */
    get selectedEntity(): EntityType;
    /**
     * @hidden @internal
     */
    onEntitySelectChanging(event: ISelectionEventArgs): void;
    /**
     * @hidden
     */
    onShowEntityChangeDialogChange(eventArgs: IChangeCheckboxEventArgs): void;
    /**
     * @hidden
     */
    onEntityChangeCancel(): void;
    /**
     * @hidden
     */
    onEntityChangeConfirm(): void;
    /**
     * @hidden @internal
     */
    set selectedReturnFields(value: string[]);
    /**
     * @hidden @internal
     */
    get selectedReturnFields(): string[];
    /**
     * @hidden @internal
     */
    set selectedField(value: FieldType);
    /**
     * @hidden @internal
     */
    get selectedField(): FieldType;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    setPickerOutlet(outlet?: IgxOverlayOutletDirective | ElementRef): void;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    get isContextMenuVisible(): boolean;
    /**
     * @hidden @internal
     */
    get hasEditedExpression(): boolean;
    /**
     * @hidden @internal
     */
    addCondition(parent: ExpressionGroupItem, afterExpression?: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    addAndGroup(parent?: ExpressionGroupItem, afterExpression?: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    addOrGroup(parent?: ExpressionGroupItem, afterExpression?: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    endGroup(groupItem: ExpressionGroupItem): void;
    /**
     * @hidden @internal
     */
    commitOperandEdit(): void;
    /**
     * @hidden @internal
     */
    cancelOperandAdd(): void;
    /**
     * @hidden @internal
     */
    cancelOperandEdit(): void;
    /**
     * @hidden @internal
     */
    operandCanBeCommitted(): boolean;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    exitOperandEdit(): void;
    /**
     * @hidden @internal
     */
    isExpressionGroup(expression: ExpressionItem): boolean;
    /**
     * @hidden @internal
     */
    onChipRemove(expressionItem: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    onChipClick(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    onChipDblClick(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    enterExpressionEdit(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    clearSelection(): void;
    /**
     * @hidden @internal
     */
    enterExpressionAdd(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    contextMenuClosed(): void;
    /**
     * @hidden @internal
     */
    onKeyDown(eventArgs: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    createAndGroup(): void;
    /**
     * @hidden @internal
     */
    createOrGroup(): void;
    /**
     * @hidden @internal
     */
    deleteFilters(): void;
    /**
     * @hidden @internal
     */
    onGroupClick(groupItem: ExpressionGroupItem): void;
    /**
     * @hidden @internal
     */
    ungroup(): void;
    /**
     * @hidden @internal
     */
    deleteGroup(): void;
    /**
     * @hidden @internal
     */
    selectFilteringLogic(event: IButtonGroupEventArgs): void;
    /**
     * @hidden @internal
     */
    getConditionFriendlyName(name: string): string;
    /**
     * @hidden @internal
     */
    isDate(value: any): boolean;
    /**
     * @hidden @internal
     */
    onExpressionsScrolled(): void;
    /**
     * @hidden @internal
     */
    invokeClick(eventArgs: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    openPicker(args: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    onOutletPointerDown(event: any): void;
    /**
     * @hidden @internal
     */
    getConditionList(): string[];
    /**
     * @hidden @internal
     */
    getFormatter(field: string): (value: any, rowData?: any) => any;
    /**
     * @hidden @internal
     */
    getFormat(field: string): string;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    setAddButtonFocus(): void;
    /**
     * @hidden @internal
     */
    context(expression: ExpressionItem, afterExpression?: ExpressionItem): {
        $implicit: ExpressionItem;
        afterExpression: ExpressionItem;
    };
    /**
     * @hidden @internal
     */
    onChipSelectionEnd(): void;
    /**
     * @hidden
     */
    expanderClick(event: any, expressionItem: ExpressionOperandItem): void;
    formatReturnFields(innerTree: IFilteringExpressionsTree): string;
    isInEditMode(): boolean;
    onInEditModeChanged(expressionItem: ExpressionOperandItem): void;
    onSelectAllClicked(_event: any): void;
    getSearchValueTemplateContext(defaultSearchValueTemplate: any): any;
    private setFormat;
    private setFilters;
    private onToggleExpression;
    private toggleExpression;
    private addGroup;
    private createExpressionGroupItem;
    private createExpressionTreeFromGroupItem;
    private toggleContextMenu;
    private findSingleSelectedGroup;
    private isInsideGroup;
    private deleteItem;
    private createGroup;
    private toggleGroup;
    private toggleGroupRecursive;
    private deselectParentRecursive;
    private calculateContextMenuTarget;
    private scrollElementIntoView;
    private init;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxQueryBuilderTreeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxQueryBuilderTreeComponent, "igx-query-builder-tree", never, { "entities": { "alias": "entities"; "required": false; }; "queryBuilder": { "alias": "queryBuilder"; "required": false; }; "searchValueTemplate": { "alias": "searchValueTemplate"; "required": false; }; "parentExpression": { "alias": "parentExpression"; "required": false; }; "fields": { "alias": "fields"; "required": false; }; "expressionTree": { "alias": "expressionTree"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "resourceStrings": { "alias": "resourceStrings"; "required": false; }; }, { "expressionTreeChange": "expressionTreeChange"; "inEditModeChange": "inEditModeChange"; }, ["headerContent"], never, true, never>;
}
export {};
