import { EventEmitter, TemplateRef } from '@angular/core';
import { ElementRef, OnDestroy } from '@angular/core';
import { IQueryBuilderResourceStrings } from '../core/i18n/query-builder-resources';
import { IExpressionTree } from '../data-operations/filtering-expressions-tree';
import { IgxOverlayOutletDirective } from '../directives/toggle/toggle.directive';
import { EntityType, FieldType } from '../grids/common/grid.interface';
import { IgxQueryBuilderHeaderComponent } from './query-builder-header.component';
import { IgxQueryBuilderTreeComponent } from './query-builder-tree.component';
import { IgxIconService } from '../icon/icon.service';
import * as i0 from "@angular/core";
/**
 * A component used for operating with complex filters by creating or editing conditions
 * and grouping them using AND/OR logic.
 * It is used internally in the Advanced Filtering of the Grid.
 *
 * @example
 * ```html
 * <igx-query-builder [fields]="this.fields">
 * </igx-query-builder>
 * ```
 */
export declare class IgxQueryBuilderComponent implements OnDestroy {
    protected iconService: IgxIconService;
    /**
     * @hidden @internal
     */
    cssClass: string;
    /**
     * @hidden @internal
     */
    display: string;
    /**
     * Gets/sets whether the confirmation dialog should be shown when changing entity.
     * Default value is `true`.
     */
    showEntityChangeDialog: boolean;
    /**
     * Gets/sets the entities.
     */
    entities: EntityType[];
    /**
     * Returns the fields.
     * @hidden
     * @deprecated in version 18.2.0. Use the `entities` property instead.
     */
    get fields(): FieldType[];
    /**
     * Sets the fields.
     * @hidden
     * @deprecated in version 18.2.0. Use the `entities` property instead.
     */
    set fields(fields: FieldType[]);
    /**
    * Returns the expression tree.
    */
    get expressionTree(): IExpressionTree;
    /**
     * Sets the expression tree.
     */
    set expressionTree(expressionTree: IExpressionTree);
    /**
     * Gets the `locale` of the query builder.
     * If not set, defaults to application's locale.
     */
    locale: string;
    /**
     * Sets the resource strings.
     * By default it uses EN resources.
     */
    set resourceStrings(value: IQueryBuilderResourceStrings);
    /**
     * Returns the resource strings.
     */
    get resourceStrings(): IQueryBuilderResourceStrings;
    /**
     * Event fired as the expression tree is changed.
     *
     * ```html
     *  <igx-query-builder (expressionTreeChange)='onExpressionTreeChange()'></igx-query-builder>
     * ```
     */
    expressionTreeChange: EventEmitter<any>;
    /**
     * @hidden @internal
     */
    headerContent: IgxQueryBuilderHeaderComponent;
    /**
     * @hidden @internal
     */
    searchValueTemplate: TemplateRef<any>;
    /**
     * @hidden @internal
     */
    queryTree: IgxQueryBuilderTreeComponent;
    private destroy$;
    private _resourceStrings;
    private _expressionTree;
    private _fields;
    constructor(iconService: IgxIconService);
    /**
     * @hidden @internal
     */
    ngOnDestroy(): void;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    setPickerOutlet(outlet?: IgxOverlayOutletDirective | ElementRef): void;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    get isContextMenuVisible(): boolean;
    /**
     * @hidden @internal
     */
    clearSelection(): void;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    exitOperandEdit(): void;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    setAddButtonFocus(): void;
    onExpressionTreeChange(tree: IExpressionTree): void;
    private registerSVGIcons;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxQueryBuilderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxQueryBuilderComponent, "igx-query-builder", never, { "showEntityChangeDialog": { "alias": "showEntityChangeDialog"; "required": false; }; "entities": { "alias": "entities"; "required": false; }; "fields": { "alias": "fields"; "required": false; }; "expressionTree": { "alias": "expressionTree"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "resourceStrings": { "alias": "resourceStrings"; "required": false; }; }, { "expressionTreeChange": "expressionTreeChange"; }, ["headerContent", "searchValueTemplate"], ["igx-query-builder-header"], true, never>;
    static ngAcceptInputType_showEntityChangeDialog: unknown;
}
